---
title: pymdownx.blocks.tab
---

[Reference](https://facelessuser.github.io/pymdown-extensions/extensions/blocks/plugins/tab/){: class="reference" }

Tab blocks are aimed at replacing the Tabbed extension (see [tab documentation](https://facelessuser.github.io/pymdown-extensions/extensions/blocks/plugins/tab/#tab)).

```md
/// tab | `pip`

    :::bash
    pip install mkdocs-shadcn
///

/// tab | uv

    :::bash
    uv add mkdocs-shadcn
///

/// tab | poetry

    :::bash
    poetry add mkdocs-shadcn
///
```

/// tab | `pip`
    new: true

    :::bash
    pip install mkdocs-shadcn
///

/// tab | uv

    :::bash
    uv add mkdocs-shadcn
///

/// tab | poetry

    :::bash
    poetry add mkdocs-shadcn
///
